@@ -1,9 +1,13 @@
 package CPAN::Critic::Module::Abstract;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
+
 use Package::MoreUtil qw(list_package_contents);
 use Perinci::Sub::DepChecker qw(check_deps);
 
@@ -14,8 +18,6 @@ our @EXPORT_OK = qw(
                        declare_policy
                );
 
-our $VERSION = '0.05'; # VERSION
-
 our %PROFILES;
 our %SPEC;
 
@@ -250,6 +252,7 @@ $PROFILES{default} = $PROFILES{all};
 
 $SPEC{critique_cpan_module_abstract} = {
     v => 1.1,
+    summary => 'Critic CPAN module abstract',
     args => {
         abstract => {
             schema => 'str*',
@@ -322,7 +325,7 @@ CPAN::Critic::Module::Abstract - Critic CPAN module abstract
 
 =head1 VERSION
 
-This document describes version 0.05 of CPAN::Critic::Module::Abstract (from Perl distribution CPAN-Critic-Module-Abstract), released on 2014-12-05.
+This document describes version 0.06 of CPAN::Critic::Module::Abstract (from Perl distribution CPAN-Critic-Module-Abstract), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -342,6 +345,8 @@ Dist::Zilla plugin coming shortly.
 
 =head2 critique_cpan_module_abstract(%args) -> [status, msg, result, meta]
 
+{en_US Critic CPAN module abstract}.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -352,8 +357,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -363,7 +366,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_empty(%args) -> [status, msg, result, meta]
@@ -378,8 +381,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -389,7 +390,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_ends_with_full_stop(%args) -> [status, msg, result, meta]
@@ -404,8 +405,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -415,7 +414,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_just_module_name(%args) -> [status, msg, result, meta]
@@ -430,8 +429,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -441,7 +438,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_multiline(%args) -> [status, msg, result, meta]
@@ -456,8 +453,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -467,7 +462,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_redundancy(%args) -> [status, msg, result, meta]
@@ -482,8 +477,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -493,7 +486,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_shouting(%args) -> [status, msg, result, meta]
@@ -508,8 +501,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -519,7 +510,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_starts_with_lowercase_letter(%args) -> [status, msg, result, meta]
@@ -534,8 +525,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -545,7 +534,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_template(%args) -> [status, msg, result, meta]
@@ -560,8 +549,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -571,7 +558,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_too_long(%args) -> [status, msg, result, meta]
@@ -588,8 +575,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -599,7 +584,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_prohibit_too_short(%args) -> [status, msg, result, meta]
@@ -616,8 +601,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -627,7 +610,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 policy_require_english(%args) -> [status, msg, result, meta]
@@ -642,8 +625,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -653,7 +634,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =for Pod::Coverage ^(.*)$
 
@@ -663,7 +644,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/CPAN-Criti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-CPAN-Critic-Module-Abstract>.
+Source repository is at L<https://github.com/sharyanto/perl-CPAN-Critic-Module-Abstract>.
 
 =head1 BUGS
 
@@ -679,7 +660,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
